#[repr(u8)]pub enum Truth {
True = 0,
False = 1,
}Expand description
Whether Rows are repeated in some section of ringing.
This is shaped identically to bool, but is a different type to allow the compiler to spot
common mistakes.
Variants
Implementations