pub enum InvalidRowError {
    NoBells,
    DuplicateBell(Bell),
    BellOutOfStage(Bell, Stage),
    MissingBell(Bell),
}
All the possible ways that a Row could be invalid.

Variants



NoBells

The Row would contain no Bells



DuplicateBell(Bell)

A Bell would appear twice in the new Row (for example in 113456 or 4152357)



BellOutOfStage(Bell, Stage)

A Bell is not within the range of the Stage of the new Row (for example 7 in 12745 or 5 in 5432).



MissingBell(Bell)

A given Bell would be missing from the Row. Note that this is only generated if we already know the Stage of the new Row, otherwise the other two variants are sufficient for every case.